@@ -168,24 +168,6 @@ def send_email(from_addr, to_addrs, subject: str, body: str, smtp_config: dict,
     return result
 
 
-def send_mail(from_addr, to_addrs, subject: str, body: str, smtp_config: dict, debug: bool=False) -> dict:
-    """Alias to send_email
-    """
-    return send_email(from_addr, to_addrs, subject, body, smtp_config, debug)
-
-
-def email(from_addr, to_addrs, subject: str, body: str, smtp_config: dict, debug: bool=False) -> dict:
-    """Alias to send_email
-    """
-    return send_email(from_addr, to_addrs, subject, body, smtp_config, debug)
-
-
-def mail(from_addr, to_addrs, subject: str, body: str, smtp_config: dict, debug: bool=False) -> dict:
-    """Alias to send_email
-    """
-    return send_email(from_addr, to_addrs, subject, body, smtp_config, debug)
-
-
 def alignment(s, space, align='left'):
     """中英文混排对齐
     中英文混排时对齐是比较麻烦的，一个先决条件是必须是等宽字体，每个汉字占2个英文字符的位置。
@@ -216,6 +198,7 @@ def alignment(s, space, align='left'):
         s1 = ' ' * (space // 2) + s + ' ' * (space - space // 2)
     return s1
 
+
 def get_win_dir(name):
     r"""Get windows folder path
        Read from \HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders
@@ -375,24 +358,6 @@ class AppTool(object):
         return send_email(mail['from'], mail_to, subject, body, smtp, debug)
 
 
-    def email(self, subject: str, body: str, to_addrs=None, debug: bool=False) -> dict:
-        """Alias to send_email
-        """
-        return self.send_email(subject, body, to_addrs, debug)
-
-    
-    def mail(self, subject: str, body: str, to_addrs=None, debug: bool=False) -> dict:
-        """Alias to send_email
-        """
-        return self.send_email(subject, body, to_addrs, debug)
-
-
-    def send_mail(self, subject: str, body: str, to_addrs=None, debug: bool=False) -> dict:
-        """Alias to send_email
-        """
-        return self.send_email(subject, body, to_addrs, debug)
-
-
     def debug(self, msg, *args, **kwargs):
         self._logger.debug(msg, *args, **kwargs)
 
